grok-py
=======

The Python client library for the `Grok REST API`_. See
https://www.groksolutions.com/devs/ for additional resources.

.. _Grok REST API: https://www.groksolutions.com/docs/devs/api/

Installation
------------

grokpy includes a `setuptools`_-compatible setup.py for your
convenience. Dependencies are listed in setup.py and will be installed
automatically as part of any of the techniques listed below. Otherwise,
you will need to install the following external dependencies before
using grokpy:

-  `requests`_
-  `certifi`_
-  `nose`_

.. _setuptools: https://pypi.python.org/pypi/setuptools
.. _requests: https://pypi.python.org/pypi/requests
.. _certifi: https://pypi.python.org/pypi/certifi
.. _nose: https://pypi.python.org/pypi/nose